@@ -63,7 +63,7 @@ sub openTree
 {
     my @TREEVIEW;
 
-    #   system("pod2html --noindex --title=Treeview.pm --infile=../../lib/HTML/Menu/TreeView.pm  --outfile=html-menu-treeview.html");
+#       system("pod2html --noindex --title=Treeview.pm --infile=lib/HTML/Menu/TreeView.pm  --outfile=../htdocs/html-menu-treeview.html");
     use Fcntl qw(:flock);
     use Symbol;
     my $fh   = gensym;
@@ -74,7 +74,7 @@ sub openTree
     close $fh;
 
     for (@lines) {
-        if ($_ =~ /<a href="#([^"]+)">(.+)<\/a>/) {
+        if ($_ =~ /<h\d id="([^"]+)">(.+)<\/h\d>/) {
             push @TREEVIEW,
               {
                 text   => $2,
