@@ -2,7 +2,7 @@
 use strict;
 use CGI qw(-compile :all :cgi-lib -private_tempfiles);
 use CGI::Carp qw(fatalsToBrowser);
-use lib qw(..);
+use lib qw(lib);
 use HTML::Menu::TreeView qw(:all);
 use vars qw(@tree $m_sContent %tempNode $tN $m_nRid);
 my $action   = param('action') ? param('action') : "editable";
@@ -14,101 +14,144 @@ $size = ($size == 22 or $size == 16 or $size == 48) ? $size : 32;
 size($size);
 clasic(1) if (defined param('clasic'));
 my $jspart = qq|
-var size = $size;
+//<<drag&drop
 var dragobjekt = null;
 var dragX = 0;
 var dragY = 0;
 var posX = 0;
 var posY = 0;
-var dropenabled = true;
+var dropenabled = false;
 document.onmousemove = drag;
 document.onmouseup = drop;
-var dropText = null;
-var dropzone = null;
-var dropid = null;
-var m_bOver = true;
-function startdrag(element){
-dropid = element;
-dragobjekt = document.getElementById(element);
-dragX = posX - dragobjekt.offsetLeft;
-dragY = posY - dragobjekt.offsetTop;
-}
-function drop() {
-
-if(dropenabled){
+dropText = null;
+dropzone = null;
+dropid = null;
 m_bOver = true;
-if(dragobjekt){
-dragobjekt.style.cursor = "";
-dragobjekt.style.position ="";
-dragobjekt = null;
-}
+m_bNoDrop = false;
+offsetLeft = 0;
+size = $size;
+function startdrag(element){
+  dropid = element;
+  dragobjekt = document.getElementById(element);
+  dragX = posX - dragobjekt.offsetLeft;
+  dragY = posY - dragobjekt.offsetTop;
 }
+function drop(){
+  if(dropenabled && dragobjekt && !m_bNoDrop){
+    m_bOver = true;
+    dragobjekt.style.cursor = "";
+    dragobjekt.style.position ="";
+  }
+  if(!m_bNoDrop)
+    dragobjekt = null;
 }
 function drag(EVENT) {
-posX = document.all ? window.event.clientX : EVENT.pageX;
-posY = document.all ? window.event.clientY : EVENT.pageY;
-if(dragobjekt){
-dragobjekt.style.cursor ="pointer";
-var os = dropenabled ? 25 : 0;
-dragobjekt.style.left = (posX - dragX)+os+"px";
-dragobjekt.style.top = (posY - dragY)+0+"px";
-}
+  posX = document.all ? window.event.clientX : EVENT.pageX;
+  posY = document.all ? window.event.clientY : EVENT.pageY;
+    
+  if(dragobjekt && !m_bNoDrop){
+    dragobjekt.style.cursor ="pointer";
+    dragobjekt.style.left = (posX -dragX )+"px";
+    dragobjekt.style.top = (posY - dragY)+"px";
+  }
 }
+//drag&drop>>
+
 function prepareMove(id){
-dragobjekt = document.getElementById(id);
-dragX = posX - dragobjekt.offsetLeft;
-dragY = posY - dragobjekt.offsetTop;
-dropenabled = true;
-m_bOver = false;
-var o = getElementPosition(id);
-move(id,o.x+25,o.y+25);
-startdrag(id);
+  dragobjekt = document.getElementById(id);
+  dragX = posX - dragobjekt.offsetLeft;
+  dragY = posY - dragobjekt.offsetTop;
+  dropenabled = true;
+  m_bOver = false;
+  var o = getElementPosition(id);
+  move(id,o.x+25,o.y+25);
+  startdrag(id);
 }
 function enableDropZone(id){
-if(!dragobjekt) return;
-dropzone = id;
-if(dragobjekt.id != dropzone) document.getElementById(id).className = "dropzone"+size;
+      if(!dragobjekt) return;
+      dropzone = id;
+      if(dragobjekt.id != dropzone) document.getElementById(id).className = "dropzone"+size;
 }
 function disableDropZone(id){
-document.getElementById(id).className = "treeviewLink"+size;
+	document.getElementById(id).className = "treeviewLink"+size;
 }
 function confirmMove(){
-
+  m_bNoDrop = true;
   if(dropzone && dragobjekt.id != dropzone){
-  var url = "$ENV{SCRIPT_NAME}?action=MoveTreeViewEntry&dump=$dump&from="+document.getElementById(dropid).id+"&to="+document.getElementById(dropzone).id+"#"+document.getElementById(dropzone).id;
-        var move = confirm("hierher verschieben ?");
-        if(move){
-          location.href =url;
-        }else{
-          dragobjekt.style.position ="";
-          dropenabled = false;
-          dragobjekt.className = "treeviewlink";
-          dragobjekt = null;
-        }
-   }
-
+    moveHere("Move "+dragobjekt.innerHTML+" to "+document.getElementById(dropzone).innerHTML+" ?" ,function(){
+    location.href = "edit.pl?action=MoveTreeViewEntry&dump=./tree.pl&from="+document.getElementById(dropid).id+"&to="+document.getElementById(dropzone).id+"#"+document.getElementById(dropzone).id;
+    });
+  }
   m_bOver = true;
 }
-function getElementPosition(id){
-var node = document.getElementById(id);
-var offsetLeft = 0;
-var offsetTop = 0;
-while (node){
-offsetLeft += node.offsetLeft;
-offsetTop += node.offsetTop;
-node = node.offsetParent;
+function moveHere(txt,sub,arg,arg2,arg3)
+{
+  visible('moveHere');
+  window.document.title = txt;
+  setText('moveHere','<div id="moveButton" class="moveButton" style="padding:0.4em;">Move Here</div><div id="moveCancelButton" class="moveButton" style="padding:0.4em;">Cancel</div>');
+  var node = document.getElementById("moveButton");
+  document.getElementById('moveHere').style.position ="absolute";
+  document.getElementById('moveHere').style.left = (posX -dragX )+"px";
+  document.getElementById('moveHere').style.top  = (posY - dragY)+"px";  
+ 
+  node.addEventListener ('click',function (evt){
+    stopDrop();
+    evt.stopPropagation();
+    sub(arg,arg2,arg3);
+  });
+  var node2 = document.getElementById("moveCancelButton");
+  node2.addEventListener ('click',function (evt){
+    stopDrop();
+    evt.stopPropagation();
+  });
 }
-var position = new Object();
-position.x = offsetLeft;
-position.y = offsetTop;
-return position;
-
+function stopDrop(){
+  hide('moveHere');
+  dragobjekt.style.position ="";
+  dropenabled = false;
+  dragobjekt.className = "treeviewLink"+size;
+  dragobjekt = null;
+  m_bNoDrop = false;
+}
+function getElementPosition(id){
+  var node = document.getElementById(id);
+  var offsetLeft = 0;
+  var offsetTop  = 0;
+  while (node){
+    offsetLeft += node.offsetLeft;
+    offsetTop += node.offsetTop;
+    node = node.offsetParent;
+  }
+  var position = new Object();
+  position.x = offsetLeft;
+  position.y = offsetTop;
+  return position;
 }
 function move(id,x,y){
-Element = document.getElementById(id);
-Element.style.position = "absolute";
-Element.style.left = x + "px";
-Element.style.top  = y + "px";
+  Element = document.getElementById(id);
+  Element.style.position = "absolute";
+  Element.style.left = x + "px";
+  Element.style.top  = y + "px";
+}
+function setText(id,string){
+var element = document.getElementById(id);
+if(element)
+element.innerHTML = string;
+else
+window.status = id+string;
+}
+function getText(id){
+var element = document.getElementById(id);
+if(element)
+return element.innerHTML;
+}
+function hide(id){
+if(document.getElementById(id))
+document.getElementById(id).style.display = "none";
+}
+function visible(id){
+      if(document.getElementById(id))
+      document.getElementById(id).style.display = "";
 }
 |;
 
@@ -137,14 +180,6 @@ if ($#tree == -1) {
                              'id'      => 'a3',
                              'rid'     => 3
                             },
-                            {
-                             'target'  => '_parent',
-                             'href'    => 'http://lindnerei.svn.sourceforge.net/viewvc/lindnerei/treeview/',
-                             'text'    => 'Subversion',
-                             'subtree' => [],
-                             'id'      => 'a4',
-                             'rid'     => 4
-                            }
               ],
               'id'  => 'a1',
               'rid' => 1
@@ -294,7 +329,7 @@ if ($#tree == -1) {
              },
              {
               'text'    => 'Kontakt',
-              'href'    => 'mailto:dirk.lindner@gmx.de',
+              'href'    => 'mailto:dirk.lze@gmail.com',
               'subtree' => [],
               'id'      => 'a22',
               'rid'     => 22
@@ -341,10 +376,28 @@ print(
     start_html(
                -title  => 'Edit',
                -script => jscript() . preload() . $jspart,
-               -style  => {-code => css()}
+               -style  => {-code => css().qq|
+               .moveHereContent{
+		  background-color:rgba(214, 210, 208,0.9);
+		  -webkit-box-shadow:0px 0px 1px rgba(0,0,0,0.4);/*black */
+		  -moz-box-shadow:0px 0px 1px rgba(0,0,0,0.4);/*black */
+		  box-shadow:0px 0px 1px black;
+		  z-index:3;
+		}
+		.moveButton{
+		  background-color:rgba(255,255,255,0.1);
+		  cursor:pointer;
+		}
+		.moveButton:hover{
+		  background-color:rgba(134, 171, 218,0.2);
+		  cursor:pointer;
+		}
+               |
+               }
     ),
     $zoom
       . br() . '
+<div id="moveHere" style="display:none;" class="moveHereContent" width="100px"></div>
 <script language="javascript" type="text/javascript">
 if (typeof document.body.onselectstart!="undefined") //ie
 document.body.onselectstart=function(){return false};
