@@ -4,10 +4,8 @@ use warnings;
 require Exporter;
 use 5.00600;
 use utf8;
-no warnings  'deprecated'; 
-
 use vars qw($DefaultClass %EXPORT_TAGS @EXPORT_OK @ISA %anker @TreeView %openArrays @caption $columns $clasic $ffirst $sort $border $orderby $size $style $orderbyColumn $prefix $bTrOver $desc %anker %ankerG $lang);
-$HTML::Menu::TreeView::VERSION = '1.17';
+$HTML::Menu::TreeView::VERSION = '1.18';
 @ISA                           = qw(Exporter);
 @HTML::Menu::TreeView::EXPORT_OK =
   qw(border Tree css columns jscript setStyle setDocumentRoot getDocumentRoot setSize setClasic clasic preload help folderFirst size style Style documentRoot loadTree saveTree  %anker %ankerG sortTree orderBy orderByColumn prefix setModern border TrOver desc language);
@@ -190,6 +188,9 @@ HTML::Menu::TreeView is a Modul to build an Html TreeView.
 
 =head1 Changes
 
+1.18
+    like 1.17 but at some other places
+    
 1.17
     #defined @{@$tree[$i]->{subtree}} don't works with perl > 5.20
     
@@ -1142,9 +1143,8 @@ sub initTree
     for (my $i = 0; $i < @$tree; $i++) {
         next if ref @$tree[$i] ne "HASH";
         $length--;
-#         no warnings  'deprecated';
-        if (defined @$tree[$i]) {#defined @{@$tree[$i]->{subtree}}
-             if ( ref @$tree[$i]->{subtree}[0] eq  "HASH"  and not defined @$tree[$i]->{empty}) {#a smalll fix, sorting closed folders will work with this change.
+        if ( @$tree[$i]) {#defined @{@$tree[$i]->{subtree}}
+             if ( ref @$tree[$i]->{subtree}[0] eq  "HASH" and  not defined @$tree[$i]->{empty}) {#a smalll fix, sorting closed folders will work with this change.
                 if ($length > 0) {
                     $self->appendFolder(@$tree[$i], \@{@$tree[$i]->{subtree}});
                 } elsif ($length eq 0) {
@@ -1176,13 +1176,14 @@ this function is used within initTree for sorting the TreeView if folderFirst(1)
         SWITCH: {
             return -1 if ref $a ne "HASH";
             return +1 if ref $b ne "HASH";
-            if (defined @{$a->{subtree}} and defined @{$b->{subtree}}) {
+            
+            if (ref $a->{subtree}[0] eq  "HASH" and ref $b->{subtree}[0] eq  "HASH" ) {
                 return lc($a->{$orderby}) cmp lc($b->{$orderby});
                 last SWITCH;
-            } elsif (defined @{$a->{subtree}}) {
+            } elsif (ref $a->{subtree}[0] eq  "HASH" ) {
                 return -1;
                 last SWITCH;
-            } elsif (defined @{$b->{subtree}}) {
+            } elsif (ref $b->{subtree}[0] eq  "HASH" ) {
                 return +1;
                 last SWITCH;
             } else {
